@@ -54,7 +54,7 @@ newest development release of Test::Simple)
 
 =head1 AUTHOR
 
-Mario Domgoergen <mario@domgoergen.com>
+Mario Domgoergen <mdom@cpan.org>
 
 This program is free software; you can redistribute it
 and/or modify it under the same terms as Perl itself.
